@@ -31,13 +31,15 @@
 #' # get a specific learner from mlr_learners:
 #' mlr_learners$get("surv.coxph")
 #' lrn("surv.coxph")
-LearnerSurv = R6Class("LearnerSurv", inherit = Learner,
+LearnerSurv = R6Class("LearnerSurv",
+  inherit = Learner,
   public = list(
     #' @description Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function(id, param_set = ParamSet$new(), predict_types = "distr", feature_types = character(), properties = character(), packages = character(),
-                          man = NA_character_) {
-      super$initialize(id = id, task_type = "surv", param_set = param_set, predict_types = predict_types,
-                       feature_types = feature_types, properties = properties, packages = packages, man = man)
+      man = NA_character_) {
+      super$initialize(
+        id = id, task_type = "surv", param_set = param_set, predict_types = predict_types,
+        feature_types = feature_types, properties = properties, packages = packages, man = man)
     }
   )
 )
