@@ -36,10 +36,12 @@ MeasureSurvGrafSE = R6::R6Class("MeasureSurvGrafSE",
 
   private = list(
     .score = function(prediction, ...) {
-      integrated_se(score = weighted_graf(truth = prediction$truth,
-                                          distribution = prediction$distr,
-                                          times = self$times),
-                    integrated = self$integrated)
+      integrated_se(
+        score = weighted_graf(
+          truth = prediction$truth,
+          distribution = prediction$distr,
+          times = self$times),
+        integrated = self$integrated)
     }
   )
 )
