@@ -42,17 +42,17 @@ MeasureSurvIntLogloss = R6::R6Class("MeasureSurvIntLogloss",
       )
 
       assertNumeric(eps)
-      private$.eps <- eps
+      private$.eps = eps
     }
   ),
 
   active = list(
-    eps = function(eps){
-      if(missing(eps))
+    eps = function(eps) {
+      if (missing(eps)) {
         return(private$.eps)
-      else {
+      } else {
         assertNumeric(eps)
-        private$.eps <- eps
+        private$.eps = eps
       }
     }
   ),
@@ -60,12 +60,14 @@ MeasureSurvIntLogloss = R6::R6Class("MeasureSurvIntLogloss",
   private = list(
     .eps = numeric(0),
     .score = function(prediction, ...) {
-      integrated_score(score = weighted_logloss(truth = prediction$truth,
-                                                distribution = prediction$distr,
-                                                times = self$times,
-                                                eps = self$eps),
-                       integrated = self$integrated,
-                       method = self$method)
+      integrated_score(
+        score = weighted_logloss(
+          truth = prediction$truth,
+          distribution = prediction$distr,
+          times = self$times,
+          eps = self$eps),
+        integrated = self$integrated,
+        method = self$method)
     }
   )
 )
