@@ -1,6 +1,5 @@
 #' @template surv_measure
 #' @templateVar title Mean Absolute Error
-#' @templateVar inherit [MeasureSurv]
 #' @templateVar fullname MeasureSurvMAE
 #'
 #' @description
@@ -17,6 +16,7 @@
 MeasureSurvMAE = R6::R6Class("MeasureSurvMAE",
   inherit = MeasureSurv,
   public = list(
+    #' @description Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       super$initialize(
         id = "surv.mae",
@@ -24,9 +24,11 @@ MeasureSurvMAE = R6::R6Class("MeasureSurvMAE",
         minimize = TRUE,
         predict_type = "response"
       )
-    },
+    }
+  ),
 
-    score_internal = function(prediction, ...) {
+  private = list(
+    .score = function(prediction, ...) {
       mean(surv_mae(prediction$truth, prediction$response)$mae)
     }
   )
