@@ -27,18 +27,18 @@ MeasureSurvSongTPR = R6Class("MeasureSurvSongTPR",
   inherit = MeasureSurvAUC,
   public = list(
     #' @description Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(times = 0, lp_thresh = 0, type = c("incident","cumulative")) {
-
+    initialize = function(times = 0, lp_thresh = 0, type = c("incident", "cumulative")) {
       assertNumeric(times, len = 1)
 
-      super$initialize(integrated = FALSE,
-                       times = times,
-                       id = "surv.songTPR",
-                       properties = c("requires_task", "requires_train_set", "requires_learner"))
+      super$initialize(
+        integrated = FALSE,
+        times = times,
+        id = "surv.songTPR",
+        properties = c("requires_task", "requires_train_set", "requires_learner"))
 
       assertNumeric(lp_thresh, len = 1)
       private$.lp_thresh = lp_thresh
-      private$.type <- match.arg(type)
+      private$.type = match.arg(type)
     }
   ),
 
@@ -52,14 +52,15 @@ MeasureSurvSongTPR = R6Class("MeasureSurvSongTPR",
       }
     },
 
-    type = function(type){
+    type = function(type) {
       if (missing(type)) {
         return(private$.type)
       } else {
-        type = c("incident", "cumulative")[pmatch(type, c("incident","cumulative"))]
-        if(is.na(type))
+        type = c("incident", "cumulative")[pmatch(type, c("incident", "cumulative"))]
+        if (is.na(type)) {
           stop("'type' must be on: 'incident', 'cumulative'. Abbreviations allowed.")
-        private$.type <- type
+        }
+        private$.type = type
       }
     }
   ),
@@ -68,13 +69,14 @@ MeasureSurvSongTPR = R6Class("MeasureSurvSongTPR",
     .lp_thresh = numeric(0),
     .type = character(0),
     .score = function(prediction, learner, task, train_set, ...) {
-      tpr = super$.score(prediction = prediction,
-                         learner = learner,
-                         task = task,
-                         train_set = train_set,
-                         FUN = survAUC::sens.sh,
-                         type = self$type,
-                         ...
+      tpr = super$.score(
+        prediction = prediction,
+        learner = learner,
+        task = task,
+        train_set = train_set,
+        FUN = survAUC::sens.sh,
+        type = self$type,
+        ...
       )
 
       tpr[, findInterval(self$lp_thresh, sort(unique(prediction$lp)))]
