@@ -1,11 +1,13 @@
-weighted_survival_score = function(truth, distribution, times, loss,...){
+weighted_survival_score = function(truth, distribution, times, loss, ...) {
   # get unique observation times (death and censoring) and order accordingly
-  obs_times = truth[ ,1]
+
+  obs_times = truth[, 1]
   unique_times = sort(unique(obs_times))
-  if(length(times) != 0) {
+  if (length(times) != 0) {
     times = unique(times[times >= min(unique_times) & times <= max(unique_times)])
-    if (length(times) == 0)
-      stop(sprintf("Times are all outside the observed range, [%s,%s].",min(obs_times),max(obs_times)))
+    if (length(times) == 0) {
+      stop(sprintf("Times are all outside the observed range, [%s,%s].", min(obs_times), max(obs_times)))
+    }
     unique_times = unique(unique_times[findInterval(times, unique_times, TRUE, TRUE)])
   }
 
@@ -18,7 +20,7 @@ weighted_survival_score = function(truth, distribution, times, loss,...){
   alive = apply(alive, 2, as.numeric)
 
   # calculated unweighted loss
-  score = loss(alive = alive, distribution = distribution, unique_times = unique_times,...)
+  score = loss(alive = alive, distribution = distribution, unique_times = unique_times, ...)
 
   # To account for censoring the score is weighted according to each individuals contribution to
   # censoring.
@@ -35,9 +37,9 @@ weighted_survival_score = function(truth, distribution, times, loss,...){
   weights_mat = weights_mat + (alive * unique_times_mat) + ((1 - alive) * obs_times_mat)
 
   # Find the Kaplan-Meier estimate of the censoring distribution, save as distr6 object
-  cens_dist = survival::survfit(Surv(time, 1-event) ~ 1, data = data.frame(time = truth[,1], event = truth[,2]))
+  cens_dist = survival::survfit(Surv(time, 1 - event) ~ 1, data = data.frame(time = truth[, 1], event = truth[, 2]))
   cens_dist = distr6::WeightedDiscrete$new(data.frame(x = cens_dist$time, cdf = 1 - cens_dist$surv),
-                                           decorators = "ExoticStatistics")
+    decorators = "ExoticStatistics")
 
   # Find the estimated censoring probability at each of the respective times derived above
   weights_mat = apply(weights_mat, 1, function(x) cens_dist$survival(x))
