@@ -5,11 +5,11 @@ test_that("autotest", {
   learner = lrn("surv.coxph")
   expect_learner(learner)
   # no idea why weights check here fails
-  result = run_autotest(learner, exclude = "weights")
+  result = run_autotest(learner, exclude = "weights", check_replicable = FALSE)
   expect_true(result, info = result$error)
 })
 
-test_that("weights",{
+test_that("weights", {
   learner = lrn("surv.coxph")
   task = generate_tasks.LearnerSurv(learner)$weights
   expect_silent(learner$train(task))
@@ -17,7 +17,7 @@ test_that("weights",{
 })
 
 
-test_that("missing",{
+test_that("missing", {
   task = TaskGeneratorSimsurv$new()$generate(50)
   learner = lrn("surv.coxph")
   learner$train(task)
