@@ -6,10 +6,11 @@ test_that("mlr_measures", {
   keys = mlr_measures$keys("^surv")
 
   for (key in keys) {
-    if(grepl("TNR|TPR", key))
+    if (grepl("TNR|TPR", key)) {
       m = mlr_measures$get(key, times = 60)
-    else
+    } else {
       m = mlr_measures$get(key)
+    }
 
     expect_measure(m)
 
@@ -25,12 +26,12 @@ times = 60
 train_set = 1:175
 
 test_that("unintegrated_prob_losses", {
-  msr = lapply(c("surv.logloss","surv.loglossSE"), msr)
+  msr = lapply(c("surv.logloss", "surv.loglossSE"), msr)
   expect_silent(prediction$score(msr))
 })
 
 test_that("integrated_prob_losses", {
-  probs = paste0("surv.", c("graf","grafSE","intlogloss","intloglossSE"))
+  probs = paste0("surv.", c("graf", "grafSE", "intlogloss", "intloglossSE"))
   expect_error(lapply(probs, msr, times = 34:37, integrated = FALSE), "non-integrated score")
   expect_silent(prediction$score(lapply(probs, msr, integrated = TRUE)))
   expect_error(prediction$score(lapply(probs, msr, integrated = TRUE, times = c(34:70))), "Times are all")
